import { DetailProps, EASY_DETAIL_TYPE } from './types';
import ACard from 'ant-design-vue/es/card';
import ADescriptions from 'ant-design-vue/es/descriptions';
import DictText from '../DictText';
import EImage from '../Image';
import OssImage from '../OssImage';
var ADescriptionsItem = ADescriptions.Item;
export default {
  name: 'EDetailInfo',
  props: DetailProps,
  computed: {
    colProp: function colProp() {
      return {
        xs: this._getColumn(3),
        sm: this._getColumn(2),
        md: this._getColumn(1)
      };
    }
  },
  methods: {
    /**
     * 获取列宽
     * @param size
     * @returns {string|number}
     * @private
     */
    _getColumn: function _getColumn() {
      var size = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
      return (this.column / size).toFixed(0) || 1;
    },

    /**
     * 获取文字的值
     * @param item
     * @returns {string|*|T|string}
     * @private
     */
    _getItemValue: function _getItemValue(item) {
      if (item.getValue) {
        return item.getValue(this.data);
      }

      if (this.data && this.data[item.key]) {
        return this.data[item.key];
      } else {
        return item.defaultValue === undefined ? '-' : item.defaultValue;
      }
    },

    /**
     * 获取枚举的值
     * @param item
     * @returns {string|*}
     * @private
     */
    _getEnumValue: function _getEnumValue(item) {
      if (this.data && this.data[item.key]) {
        var value = this.data[item.key];

        if (item.enumList) {
          var valueObj = item.enumList.find(function (enumItem) {
            return enumItem.value === value;
          });
          return valueObj ? valueObj.label : value;
        }
      } else {
        return item.defaultValue === undefined ? '-' : item.defaultValue;
      }
    },

    /**
     * 获取图片的值
     * @param item
     * @returns {*}
     * @private
     */
    _getImgValue: function _getImgValue(item) {
      return this.data && this.data[item.key] || item.defaultValue;
    },

    /**
     * 渲染字典类型的文字
     * @private
     */
    _renderDictText: function _renderDictText(item) {
      var h = this.$createElement;
      return h(DictText, {
        attrs: {
          dictId: item.dictId,
          name: this._getItemValue(item)
        }
      });
    },

    /**
     * 渲染枚举类型的文字
     * @private
     */
    _renderEnumText: function _renderEnumText(item) {
      var h = this.$createElement;
      return h("div", [this._getEnumValue(item)]);
    },

    /**
     * 渲染普通文字
     * @private
     */
    _renderNormalText: function _renderNormalText(item) {
      var h = this.$createElement;
      return h("div", [this._getItemValue(item)]);
    },

    /**
     * 渲染文字部分的ui
     * @returns {JSX.Element}
     * @private
     */
    _renderInfoList: function _renderInfoList() {
      var _this = this;

      var h = this.$createElement;
      return h(ADescriptions, {
        attrs: {
          column: this.colProp
        }
      }, [this.$props.infoList.map(function (item) {
        return _this._getItemValue(item) ? h(ADescriptionsItem, {
          attrs: {
            label: item.title
          }
        }, [item.type === EASY_DETAIL_TYPE.DICT ? _this._renderDictText(item) : null, item.type === EASY_DETAIL_TYPE.ENUM ? _this._renderEnumText(item) : null, item.type === EASY_DETAIL_TYPE.TEXT ? _this._renderNormalText(item) : null]) : null;
      })]);
    },

    /**
     * 渲染图片部分的ui
     * @private
     */
    _renderImgList: function _renderImgList() {
      var _this2 = this;

      var h = this.$createElement;
      return h(ADescriptions, {
        attrs: {
          column: this.colProp
        }
      }, [this.$props.imgList.map(function (item) {
        return h(ADescriptionsItem, {
          attrs: {
            label: item.title
          }
        }, [_this2.$props.useOssSTSPolicy ? h(OssImage, {
          attrs: {
            url: _this2._getImgValue(item)
          }
        }) : h(EImage, {
          attrs: {
            url: _this2._getImgValue(item)
          }
        })]);
      })]);
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$props = this.$props,
        cardTitle = _this$$props.cardTitle,
        infoList = _this$$props.infoList,
        imgList = _this$$props.imgList;
    return h(ACard, {
      attrs: {
        title: cardTitle,
        bordered: false
      }
    }, [infoList && infoList.length > 0 ? this._renderInfoList() : null, imgList && imgList.length > 0 ? this._renderImgList() : null]);
  }
};