"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _babelHelperVueJsxMergeProps = _interopRequireDefault(require("babel-helper-vue-jsx-merge-props"));

var _modal = _interopRequireDefault(require("ant-design-vue/es/modal"));

var _types = require("./types");

var _Loading = _interopRequireDefault(require("../Loading"));

require("./style.less");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * 图片组件
 */
var _default = {
  name: 'EImage',
  props: _types.ImageProps,
  data: function data() {
    return {
      previewModalVisible: false,
      // 预览模态是否显示
      isLoading: true,
      // 是否在加载中
      loadImageSuccess: false
    };
  },
  methods: {
    /**
     * 获取图片的显示绝对路径
     * @returns {*}
     * @private
     */
    _getImageTargetUrl: function _getImageTargetUrl() {
      return this.$props.url;
    },

    /**
     * loading结束
     * @param loadImageSuccess 图片加载是否成功
     * @private
     */
    _loadingFinish: function _loadingFinish() {
      var loadImageSuccess = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

      if (this.$data.isLoading) {
        this.$data.isLoading = false;
        this.$data.loadImageSuccess = loadImageSuccess;
      }
    },

    /**
     * 预览图片
     */
    previewImage: function previewImage() {
      this.$data.previewModalVisible = true;
    },

    /**
     * 隐藏预览
     */
    hidePreview: function hidePreview() {
      this.$data.previewModalVisible = false;
    },

    /**
     * 渲染预览的模态
     * @return {*}
     */
    renderPreviewModal: function renderPreviewModal() {
      var h = this.$createElement;
      var props = {
        visible: this.$data.previewModalVisible,
        footer: null,
        maskClosable: true,
        width: '960px'
      };
      return h(_modal["default"], (0, _babelHelperVueJsxMergeProps["default"])([{
        props: props
      }, {
        on: {
          "cancel": this.hidePreview
        }
      }]), [h("div", {
        "class": "preview-img-wrapper"
      }, [h("img", {
        attrs: {
          src: this._getImageTargetUrl(),
          alt: ""
        },
        "class": "preview-img"
      })])]);
    }
  },
  render: function render() {
    var _this = this;

    var h = arguments[0];
    var clickToPreview = this.$props.clickToPreview;
    var showDom = null;

    if (this.$data.isLoading) {
      // 展示loading
      showDom = [h(_Loading["default"]), h("img", {
        "class": "loading-img",
        attrs: {
          src: this._getImageTargetUrl()
        },
        on: {
          "load": function load() {
            _this._loadingFinish();
          }
        }
      })];
    } else if (this.$data.loadImageSuccess) {
      return h("div", {
        "class": "oss-image-wrapper",
        on: {
          "click": this.previewImage
        }
      }, [h("img", {
        attrs: {
          src: this._getImageTargetUrl()
        }
      }), clickToPreview ? this.renderPreviewModal() : null]);
    } else {
      showDom = '图片加载失败';
    }

    return h("div", {
      "class": "oss-image-wrapper"
    }, [showDom]);
  }
};
exports["default"] = _default;